"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeModuleGenerator = void 0;
const node_assert_1 = __importDefault(require("node:assert"));
const node_path_1 = __importDefault(require("node:path"));
const shared_1 = require("../shared");
const readme_1 = require("./readme");
class NodeModuleGenerator extends shared_1.BaseGenerator {
    constructor(args, options) {
        super(args, options, { customInstallTask: true });
        this.configureSubGenerators = () => {
            return [
                {
                    Generator: readme_1.ReadmeGenerator,
                    path: node_path_1.default.join(__dirname, "./readme"),
                },
            ];
        };
        this.writeGitignore = () => {
            this.writeOrAppendGitignore(".gitignore.ejs");
        };
        this.writePackageJson = () => {
            var _a;
            const keywordTokens = ((_a = this.answers.packageKeywords) === null || _a === void 0 ? void 0 : _a.split(" ")) || [];
            const keywords = keywordTokens.map((token) => `"${token}"`).join(", ");
            const githubUrl = `https://github.com/${this.answers.repoOwner}/${this.answers.repoName}`;
            this.copyTemplate("package.json.ejs", "package.json", Object.assign(Object.assign({}, this.answers), { keywords,
                githubUrl }));
        };
    }
    static getQuestions() {
        return [
            ...readme_1.ReadmeGenerator.getQuestions(),
            {
                type: "input",
                name: "packageKeywords",
                message: "What keywords would you like to associate with this new package?",
                default: "generated yeoman typescript",
            },
            {
                type: "input",
                name: "authorName",
                message: "Who is the author of this new package?",
                default: "Daniel Chiu",
            },
            {
                type: "input",
                name: "authorEmail",
                message: "What is the email address of the author of this new package?",
                default: "daniel@chiubaka.com",
            },
        ];
    }
    writing() {
        (0, node_assert_1.default)(this.answers);
        this.writeGitignore();
        this.writePackageJson();
    }
    async install() {
        await this.exec("yarn set version 3.2.1");
        let yarnArgs = "install";
        if (this.options.disableImmutableYarnInstalls === true) {
            yarnArgs = `${yarnArgs} --no-immutable`;
        }
        await this.exec(`yarn ${yarnArgs}`);
        await this.exec("yarn dlx @yarnpkg/sdks vscode");
    }
}
exports.NodeModuleGenerator = NodeModuleGenerator;
//# sourceMappingURL=NodeModuleGenerator.js.map